@@ -1217,7 +1217,7 @@ impl<'a> Emitter<'a> {
     #[emitter]
     fn emit_quasi(&mut self, node: &TplElement) -> Result {
         self.wr
-            .write_str_lit(node.span, &unescape(&node.raw.value))?;
+            .write_str_lit(node.span, &unescape_tpl_lit(&node.raw.value))?;
         return Ok(());
     }
 
@@ -2352,7 +2352,7 @@ where
     }
 }
 
-fn unescape(s: &str) -> String {
+fn unescape_tpl_lit(s: &str) -> String {
     fn read_escaped(
         radix: u32,
         len: Option<usize>,
@@ -2403,12 +2403,16 @@ fn unescape(s: &str) -> String {
     }
 
     let mut result = String::with_capacity(s.len() * 6 / 5);
-    let mut chars = s.chars();
+    let mut chars = s.chars().peekable();
 
     while let Some(c) = chars.next() {
         if c != '\\' {
             match c {
                 '\r' => {
+                    if chars.peek().map(|&v| v) == Some('\n') {
+                        continue;
+                    }
+
                     result.push_str("\\r");
                 }
                 '\n' => {
